@@ -4,8 +4,8 @@ import (
 	"bytes"
 	"encoding/json"
 
-	"github.com/alecthomas/chroma/quick"
-	"github.com/noahgorstein/jqp/tui/styles"
+	"github.com/alecthomas/chroma/v2"
+	"github.com/alecthomas/chroma/v2/quick"
 	"github.com/noahgorstein/jqp/tui/utils"
 )
 
@@ -14,7 +14,7 @@ func isValidJson(input []byte) bool {
 	return json.Unmarshal(input, &js) == nil
 }
 
-func highlightJson(input []byte) *bytes.Buffer {
+func highlightJson(input []byte, chromaStyle chroma.Style) *bytes.Buffer {
 
 	if isValidJson(input) {
 		var f interface{}
@@ -22,16 +22,10 @@ func highlightJson(input []byte) *bytes.Buffer {
 		var prettyJSON bytes.Buffer
 		json.Indent(&prettyJSON, []byte(input), "", "    ")
 		buf := new(bytes.Buffer)
-		quick.Highlight(buf, prettyJSON.String(), "json", "terminal16", utils.GetChromaTheme())
+		quick.Highlight(buf, prettyJSON.String(), "json", utils.GetTerminalColorSupport(), chromaStyle.Name)
 		return buf
 	}
 	buf := new(bytes.Buffer)
-	quick.Highlight(buf, string(input), "json", "terminal16", utils.GetChromaTheme())
+	quick.Highlight(buf, string(input), "json", utils.GetTerminalColorSupport(), chromaStyle.Name)
 	return buf
 }
-
-func (b *Bubble) setAllBordersInactive() {
-	b.queryinput.SetBorderColor(styles.GREY)
-	b.inputdata.SetBorderColor(styles.GREY)
-	b.output.SetBorderColor(styles.GREY)
-}
