@@ -6,12 +6,17 @@ import (
 )
 
 func (b Bubble) View() string {
+	inputoutput := []string{b.inputdata.View()}
+	if b.width%2 != 0 {
+		inputoutput = append(inputoutput, " ")
+	}
+	inputoutput = append(inputoutput, b.output.View())
 
 	if b.state == state.Save {
 		return lipgloss.JoinVertical(
 			lipgloss.Left,
 			b.queryinput.View(),
-			lipgloss.JoinHorizontal(lipgloss.Top, b.inputdata.View(), b.output.View()),
+			lipgloss.JoinHorizontal(lipgloss.Top, inputoutput...),
 			b.fileselector.View(),
 			b.statusbar.View(),
 			b.help.View())
@@ -20,7 +25,7 @@ func (b Bubble) View() string {
 	return lipgloss.JoinVertical(
 		lipgloss.Left,
 		b.queryinput.View(),
-		lipgloss.JoinHorizontal(lipgloss.Top, b.inputdata.View(), b.output.View()),
+		lipgloss.JoinHorizontal(lipgloss.Top, inputoutput...),
 		b.statusbar.View(),
 		b.help.View())
 }
