@@ -2,7 +2,6 @@ package queryinput
 
 import (
 	"github.com/charmbracelet/lipgloss"
-	"github.com/noahgorstein/jqp/tui/styles"
 )
 
 type Styles struct {
@@ -11,6 +10,6 @@ type Styles struct {
 
 func DefaultStyles() (s Styles) {
 
-	s.containerStyle = lipgloss.NewStyle().Border(lipgloss.RoundedBorder()).BorderForeground(styles.BLUE)
+	s.containerStyle = lipgloss.NewStyle().Border(lipgloss.RoundedBorder())
 	return s
 }
